@@ -6,7 +6,7 @@ from .default_caster import CastType
 from .extras import NoDefault
 
 
-@dataclass
+@dataclass(repr=False)
 class Item:
     source: Union[Hashable, list['Item']]
     cast_as: Union[None, CastType, List[CastType]]
@@ -33,3 +33,20 @@ class Item:
             return {self.source}
         else:
             return set(itertools.chain(item.source for item in self.source))
+
+    def __str__(self):
+        params = [f'{self.source!r}', self.cast_as.__name__ if isinstance(self.cast_as, type) else str(self.cast_as)]
+        if self.optional:
+            params.append('optional=True')
+        if self.default is not NoDefault:
+            params.append(f'default={self.default}')
+        if self.preprocessor is not None:
+            params.append(f'preprocessor={self.preprocessor}')
+        if self.postprocessor is not None:
+            params.append(f'postprocessor={self.postprocessor}')
+        if self.result_key != self.source is not None:
+            params.append(f'rename={self.result_key}')
+        result = f'Item({",".join(params)})'
+        return result
+
+    __repr__ = __str__
